package main

import (
	"encoding/json"
	"fmt"
	"os"
)

type GithubEvent struct {
	PullRequest struct {
		Title string `json:"title"`
	} `json:"pull_request"`
}

func main() {
	eventPath := os.Getenv("GITHUB_EVENT_PATH")
	if eventPath == "" {
		fmt.Println("GITHUB_EVENT_PATH not set")
		os.Exit(1)
	}

	eventFile, err := os.Open(eventPath)
	if err != nil {
		fmt.Printf("Error opening %s: %v\n", eventPath, err)
		os.Exit(1)
	}
	defer eventFile.Close()

	var event GithubEvent
	decoder := json.NewDecoder(eventFile)
	err = decoder.Decode(&event)
	if err != nil {
		fmt.Printf("Error decoding event.json: %v\n", err)
		os.Exit(1)
	}

	prTitle := event.PullRequest.Title
	fmt.Println("Pull Request Title:", prTitle)
}
